# Credits

## Miroslav Dobsicek  

- The first version of the tergite qiskit SDK
- HPC-QC demonstrations

## Axel Andersson  

- Support for OpenPulse
- HPC-QC demonstrations

## Stefan Hill

- HPC-QC demonstrations

## Martin Ahindura  

- Bearer token authentication
- Integration/unit plus CI/CD pipeline configurations
- e2e test suite
- Implementation of the CZ gate

## Adilet Tuleuov

- Implementation of the CZ gate

## Pontus Vikstål

- Implementation of the CZ gate

## Raiyan Yahya

- e2e test suite